/*
 * Copyright (C) Yichun Zhang (agentzh)
 *
 * WARNING: DO NOT EVER EDIT THIS FILE!!
 *
 * This file was automatically generated by the re.pl script of sregex's
 * "dfa-multi-re" git branch.
 */


#include "ngx_http_lua_lex.h"
#include <stdlib.h>
#include <stdint.h>
#include <stdio.h>
#include <ctype.h>
#include <errno.h>
#include <string.h>


#if __GNUC__ > 3
#    define likely(x)       __builtin_expect((x),1)
#    define unlikely(x)     __builtin_expect((x),0)
#else
#    define likely(x)      (x)
#    define unlikely(x)    (x)
#endif


#ifndef u_char
#define u_char          unsigned char
#endif


enum {
    NO_MATCH = -1,
};


/*
 * ngx_http_lua_lex: the "ovec" array should be allocated by the caller with at
 * least 2 elements.
 */
int
ngx_http_lua_lex(const u_char *const s, size_t len, int *const ovec)
{
    unsigned i = 0;
    int matched_0 = -1;
    int matched_1 = -1;
    int matched_id = NO_MATCH;  /* (pending) matched regex ID */
    int c;
    int caps0_0 = -1;
    int caps0_10 = -1;
    int caps0_12 = -1;
    int caps0_14 = -1;
    int caps0_2 = -1;
    int caps0_4 = -1;
    int caps0_6 = -1;
    int caps0_8 = -1;
    int caps1_0 = -1;
    int caps1_10 = -1;
    int caps1_12 = -1;
    int caps1_14 = -1;
    int caps1_2 = -1;
    int caps1_4 = -1;
    int caps1_6 = -1;
    int caps1_8 = -1;
    int caps2_0 = -1;
    int caps2_10 = -1;
    int caps2_2 = -1;
    int caps2_4 = -1;
    int caps2_6 = -1;
    int caps2_8 = -1;
    int caps3_10 = -1;

    {  /* DFA node {0} 0 */
    if (unlikely(i >= len)) {
        i++;
        goto st0_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_12 = i - 1;
        goto st2;
        break;
        }
    case 39: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_14 = i - 1;
        goto st3;
        break;
        }
    case 45: {
        /* transfer caps from row 0 to row 1 */
        /* transfer caps from row 0 to row 2 */
        /* capture stores */
        caps0_6 = i - 1;
        caps1_10 = i - 1;
        goto st4;
        break;
        }
    case 91: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_4 = i - 1;
        goto st5;
        break;
        }
    case 93: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_8 = i - 1;
        goto st6;
        break;
        }
    case 123: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_0 = i - 1;
        goto st7;
        break;
        }
    case 125: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_2 = i - 1;
        goto st8;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st1;
    }  /* end state */

    goto st0_error;

st1: {  /* DFA node {1} 1 */
    if (unlikely(i >= len)) {
        i++;
        goto st1_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_12 = i - 1;
        goto st2;
        break;
        }
    case 39: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_14 = i - 1;
        goto st3;
        break;
        }
    case 45: {
        /* transfer caps from row 0 to row 1 */
        /* transfer caps from row 0 to row 2 */
        /* capture stores */
        caps0_6 = i - 1;
        caps1_10 = i - 1;
        goto st4;
        break;
        }
    case 91: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_4 = i - 1;
        goto st5;
        break;
        }
    case 93: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_8 = i - 1;
        goto st6;
        break;
        }
    case 123: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_0 = i - 1;
        goto st7;
        break;
        }
    case 125: {
        /* transfer caps from row 0 to row 1 */
        /* capture stores */
        caps0_2 = i - 1;
        goto st8;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st1;
    }  /* end state */

    goto st1_error;

st2: {  /* DFA node {59,1} 2 */
    if (unlikely(i >= len)) {
        i++;
        goto st2_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st9;
    }  /* end state */

    goto st2_error;

st3: {  /* DFA node {72,1} 3 */
    if (unlikely(i >= len)) {
        i++;
        goto st3_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st18;
    }  /* end state */

    goto st3_error;

st4: {  /* DFA node {30,50,1} 4 */
    if (unlikely(i >= len)) {
        i++;
        goto st4_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        /* transfer caps from row 2 to row 0 */
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps0_12 = i - 1;
        goto st2;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 0 */
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps0_14 = i - 1;
        goto st3;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st27;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 0 */
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps0_4 = i - 1;
        goto st5;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 0 */
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps0_8 = i - 1;
        goto st6;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 0 */
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps0_0 = i - 1;
        goto st7;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 0 */
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps0_2 = i - 1;
        goto st8;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 0 */
    goto st1;
    }  /* end state */

    goto st4_error;

st5: {  /* DFA node {21,1} 5 */
    if (unlikely(i >= len)) {
        i++;
        goto st5_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_12 = i - 1;
        goto st2;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_14 = i - 1;
        goto st3;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 0 */
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps0_6 = i - 1;
        caps1_10 = i - 1;
        goto st4;
        break;
        }
    case 61: {
        goto st28;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st29;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_8 = i - 1;
        goto st6;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_0 = i - 1;
        goto st7;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_2 = i - 1;
        goto st8;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 1 to row 0 */
    goto st1;
    }  /* end state */

    goto st5_error;

st6: {  /* DFA node {41,1} 6 */
    if (unlikely(i >= len)) {
        i++;
        goto st6_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_12 = i - 1;
        goto st2;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_14 = i - 1;
        goto st3;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 0 */
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps0_6 = i - 1;
        caps1_10 = i - 1;
        goto st4;
        break;
        }
    case 61: {
        goto st30;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_4 = i - 1;
        goto st5;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st31;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_0 = i - 1;
        goto st7;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_2 = i - 1;
        goto st8;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 1 to row 0 */
    goto st1;
    }  /* end state */

    goto st6_error;

st7: {  /* DFA node {11,1} 7 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st8: {  /* DFA node {16,1} 8 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st9: {  /* DFA node {65,1} 9 */
    if (unlikely(i >= len)) {
        i++;
        goto st9_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st9;
    }  /* end state */

    goto st9_error;

st10: {  /* DFA node {67,59,1} 10 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st11: {  /* DFA node {65,72,1} 11 */
    if (unlikely(i >= len)) {
        i++;
        goto st11_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st35;
    }  /* end state */

    goto st11_error;

st12: {  /* DFA node {65,30,50,1} 12 */
    if (unlikely(i >= len)) {
        i++;
        goto st12_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 4 */
        /* transfer caps from row 3 to row 5 */
        /* capture stores */
        goto st44;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 1 */
    goto st9;
    }  /* end state */

    goto st12_error;

st13: {  /* DFA node {65,21,1} 13 */
    if (unlikely(i >= len)) {
        i++;
        goto st13_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 61: {
        goto st45;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st46;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st9;
    }  /* end state */

    goto st13_error;

st14: {  /* DFA node {62,1} 14 */
    if (unlikely(i >= len)) {
        i++;
        goto st14_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st48;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st49;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st50;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st51;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st52;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st53;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st54;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st47;
    }  /* end state */

    goto st14_error;

st15: {  /* DFA node {65,41,1} 15 */
    if (unlikely(i >= len)) {
        i++;
        goto st15_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 61: {
        goto st55;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st56;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st9;
    }  /* end state */

    goto st15_error;

st16: {  /* DFA node {65,11,1} 16 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st17: {  /* DFA node {65,16,1} 17 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st18: {  /* DFA node {78,1} 18 */
    if (unlikely(i >= len)) {
        i++;
        goto st18_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st18;
    }  /* end state */

    goto st18_error;

st19: {  /* DFA node {78,59,1} 19 */
    if (unlikely(i >= len)) {
        i++;
        goto st19_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st60;
    }  /* end state */

    goto st19_error;

st20: {  /* DFA node {80,72,1} 20 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st21: {  /* DFA node {78,30,50,1} 21 */
    if (unlikely(i >= len)) {
        i++;
        goto st21_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 4 */
        /* transfer caps from row 3 to row 5 */
        /* capture stores */
        goto st70;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 1 */
    goto st18;
    }  /* end state */

    goto st21_error;

st22: {  /* DFA node {78,21,1} 22 */
    if (unlikely(i >= len)) {
        i++;
        goto st22_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 61: {
        goto st71;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st72;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st18;
    }  /* end state */

    goto st22_error;

st23: {  /* DFA node {75,1} 23 */
    if (unlikely(i >= len)) {
        i++;
        goto st23_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st74;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st75;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st76;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st77;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st78;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st79;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st80;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st73;
    }  /* end state */

    goto st23_error;

st24: {  /* DFA node {78,41,1} 24 */
    if (unlikely(i >= len)) {
        i++;
        goto st24_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 61: {
        goto st81;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st82;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st18;
    }  /* end state */

    goto st24_error;

st25: {  /* DFA node {78,11,1} 25 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st26: {  /* DFA node {78,16,1} 26 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st27: {  /* DFA node {31,51,30,50,1} 27 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 91) {
            goto st88;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 90)
            || (c >= 92 && c <= 255))
        {
            /* transfer caps from row 1 to row 0 */
            caps0_10 = caps1_10;
            goto st87;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st28: {  /* DFA node {23,1} 28 */
    if (unlikely(i >= len)) {
        i++;
        goto st28_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_12 = i - 1;
        goto st2;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_14 = i - 1;
        goto st3;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 0 */
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps0_6 = i - 1;
        caps1_10 = i - 1;
        goto st4;
        break;
        }
    case 61: {
        goto st28;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st29;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_8 = i - 1;
        goto st6;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_0 = i - 1;
        goto st7;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_2 = i - 1;
        goto st8;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 1 to row 0 */
    goto st1;
    }  /* end state */

    goto st28_error;

st29: {  /* DFA node {25,21,1} 29 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_4;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 2;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st30: {  /* DFA node {43,1} 30 */
    if (unlikely(i >= len)) {
        i++;
        goto st30_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_12 = i - 1;
        goto st2;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_14 = i - 1;
        goto st3;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 0 */
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps0_6 = i - 1;
        caps1_10 = i - 1;
        goto st4;
        break;
        }
    case 61: {
        goto st30;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_4 = i - 1;
        goto st5;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st31;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_0 = i - 1;
        goto st7;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 0 */
        /* capture stores */
        caps0_2 = i - 1;
        goto st8;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 1 to row 0 */
    goto st1;
    }  /* end state */

    goto st30_error;

st31: {  /* DFA node {45,41,1} 31 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_8;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 4;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st35: {  /* DFA node {65,78,1} 35 */
    if (unlikely(i >= len)) {
        i++;
        goto st35_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st35;
    }  /* end state */

    goto st35_error;

st36: {  /* DFA node {67,78,59,1} 36 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st37: {  /* DFA node {65,80,72,1} 37 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st38: {  /* DFA node {65,78,30,50,1} 38 */
    if (unlikely(i >= len)) {
        i++;
        goto st38_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 4 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 4 to row 5 */
        /* transfer caps from row 4 to row 6 */
        /* capture stores */
        goto st91;
        break;
        }
    case 91: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        /* transfer caps from row 4 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 4 to row 2 */
    goto st35;
    }  /* end state */

    goto st38_error;

st39: {  /* DFA node {65,78,21,1} 39 */
    if (unlikely(i >= len)) {
        i++;
        goto st39_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 61: {
        goto st92;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st93;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st39_error;

st40: {  /* DFA node {62,75,1} 40 */
    if (unlikely(i >= len)) {
        i++;
        goto st40_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st95;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st96;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st97;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st98;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st99;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st100;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st101;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st94;
    }  /* end state */

    goto st40_error;

st41: {  /* DFA node {65,78,41,1} 41 */
    if (unlikely(i >= len)) {
        i++;
        goto st41_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 61: {
        goto st102;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st103;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st41_error;

st42: {  /* DFA node {65,78,11,1} 42 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 34) {
            goto st105;
        }
        if (c == 39) {
            goto st106;
        }
        if (c == 92) {
            goto st107;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st104;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st43: {  /* DFA node {65,78,16,1} 43 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 34) {
            goto st105;
        }
        if (c == 39) {
            goto st106;
        }
        if (c == 92) {
            goto st107;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st104;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st44: {  /* DFA node {65,31,51,30,50,1} 44 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st109;
        }
        if (c == 91) {
            goto st110;
        }
        if (c == 92) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st111;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st108;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st45: {  /* DFA node {65,23,1} 45 */
    if (unlikely(i >= len)) {
        i++;
        goto st45_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 61: {
        goto st45;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st46;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st9;
    }  /* end state */

    goto st45_error;

st46: {  /* DFA node {65,25,21,1} 46 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_4;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 2;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st47: {  /* DFA node {63,1} 47 */
    if (unlikely(i >= len)) {
        i++;
        goto st47_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st9;
    }  /* end state */

    goto st47_error;

st48: {  /* DFA node {63,59,1} 48 */
    if (unlikely(i >= len)) {
        i++;
        goto st48_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st9;
    }  /* end state */

    goto st48_error;

st49: {  /* DFA node {63,72,1} 49 */
    if (unlikely(i >= len)) {
        i++;
        goto st49_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st35;
    }  /* end state */

    goto st49_error;

st50: {  /* DFA node {63,30,50,1} 50 */
    if (unlikely(i >= len)) {
        i++;
        goto st50_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 4 */
        /* transfer caps from row 3 to row 5 */
        /* capture stores */
        goto st44;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 1 */
    goto st9;
    }  /* end state */

    goto st50_error;

st51: {  /* DFA node {63,21,1} 51 */
    if (unlikely(i >= len)) {
        i++;
        goto st51_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 61: {
        goto st45;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st46;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st15;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st9;
    }  /* end state */

    goto st51_error;

st52: {  /* DFA node {63,41,1} 52 */
    if (unlikely(i >= len)) {
        i++;
        goto st52_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 61: {
        goto st55;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st56;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st9;
    }  /* end state */

    goto st52_error;

st53: {  /* DFA node {63,11,1} 53 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st54: {  /* DFA node {63,16,1} 54 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st55: {  /* DFA node {65,43,1} 55 */
    if (unlikely(i >= len)) {
        i++;
        goto st55_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st10;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st11;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st12;
        break;
        }
    case 61: {
        goto st55;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st13;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st14;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st56;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st16;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st17;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st9;
    }  /* end state */

    goto st55_error;

st56: {  /* DFA node {65,45,41,1} 56 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_8;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 4;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st57: {  /* DFA node {65} 57 */
    if (unlikely(i >= len)) {
        i++;
        goto st57_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        goto st58;
        break;
        }
    case 92: {
        goto st59;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 33)
        || (c >= 35 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st57;
    }
    }  /* end state */

    goto st57_error;

st58: {  /* DFA node {67} 58 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st59: {  /* DFA node {62} 59 */
    if (unlikely(i >= len)) {
        i++;
        goto st59_error;
    }

    c = s[i];
    i++;
    if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
        goto st112;
    }
    }  /* end state */

    goto st59_error;

st60: {  /* DFA node {78,65,1} 60 */
    if (unlikely(i >= len)) {
        i++;
        goto st60_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st60;
    }  /* end state */

    goto st60_error;

st61: {  /* DFA node {78,67,59,1} 61 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st62: {  /* DFA node {80,65,72,1} 62 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st63: {  /* DFA node {78,65,30,50,1} 63 */
    if (unlikely(i >= len)) {
        i++;
        goto st63_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 4 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 4 to row 5 */
        /* transfer caps from row 4 to row 6 */
        /* capture stores */
        goto st113;
        break;
        }
    case 91: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        /* transfer caps from row 4 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 4 to row 2 */
    goto st60;
    }  /* end state */

    goto st63_error;

st64: {  /* DFA node {78,65,21,1} 64 */
    if (unlikely(i >= len)) {
        i++;
        goto st64_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 61: {
        goto st114;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st115;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st64_error;

st65: {  /* DFA node {75,62,1} 65 */
    if (unlikely(i >= len)) {
        i++;
        goto st65_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st117;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st118;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st119;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st120;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st121;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st122;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st123;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c == 92)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st116;
    }  /* end state */

    goto st65_error;

st66: {  /* DFA node {78,65,41,1} 66 */
    if (unlikely(i >= len)) {
        i++;
        goto st66_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 61: {
        goto st124;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st125;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st66_error;

st67: {  /* DFA node {78,65,11,1} 67 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 34) {
            goto st127;
        }
        if (c == 39) {
            goto st128;
        }
        if (c == 92) {
            goto st129;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st126;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st68: {  /* DFA node {78,65,16,1} 68 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 34) {
            goto st127;
        }
        if (c == 39) {
            goto st128;
        }
        if (c == 92) {
            goto st129;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st126;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st70: {  /* DFA node {78,31,51,30,50,1} 70 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 39) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st131;
        }
        if (c == 91) {
            goto st132;
        }
        if (c == 92) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st133;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st130;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st71: {  /* DFA node {78,23,1} 71 */
    if (unlikely(i >= len)) {
        i++;
        goto st71_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 61: {
        goto st71;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st72;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st18;
    }  /* end state */

    goto st71_error;

st72: {  /* DFA node {78,25,21,1} 72 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_4;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 2;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st73: {  /* DFA node {76,1} 73 */
    if (unlikely(i >= len)) {
        i++;
        goto st73_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 1 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 1 to row 2 */
        /* transfer caps from row 1 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 91: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 1 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st18;
    }  /* end state */

    goto st73_error;

st74: {  /* DFA node {76,59,1} 74 */
    if (unlikely(i >= len)) {
        i++;
        goto st74_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st60;
    }  /* end state */

    goto st74_error;

st75: {  /* DFA node {76,72,1} 75 */
    if (unlikely(i >= len)) {
        i++;
        goto st75_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st18;
    }  /* end state */

    goto st75_error;

st76: {  /* DFA node {76,30,50,1} 76 */
    if (unlikely(i >= len)) {
        i++;
        goto st76_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 4 */
        /* transfer caps from row 3 to row 5 */
        /* capture stores */
        goto st70;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 1 */
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 1 */
    goto st18;
    }  /* end state */

    goto st76_error;

st77: {  /* DFA node {76,21,1} 77 */
    if (unlikely(i >= len)) {
        i++;
        goto st77_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 61: {
        goto st71;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st72;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_8 = i - 1;
        goto st24;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st18;
    }  /* end state */

    goto st77_error;

st78: {  /* DFA node {76,41,1} 78 */
    if (unlikely(i >= len)) {
        i++;
        goto st78_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 61: {
        goto st81;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st82;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st18;
    }  /* end state */

    goto st78_error;

st79: {  /* DFA node {76,11,1} 79 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st80: {  /* DFA node {76,16,1} 80 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st81: {  /* DFA node {78,43,1} 81 */
    if (unlikely(i >= len)) {
        i++;
        goto st81_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_12 = i - 1;
        goto st19;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_14 = i - 1;
        goto st20;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 1 */
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps1_6 = i - 1;
        caps2_10 = i - 1;
        goto st21;
        break;
        }
    case 61: {
        goto st81;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_4 = i - 1;
        goto st22;
        break;
        }
    case 92: {
        /* transfer caps from row 2 to row 1 */
        goto st23;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st82;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_0 = i - 1;
        goto st25;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 1 */
        /* capture stores */
        caps1_2 = i - 1;
        goto st26;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 2 to row 1 */
    goto st18;
    }  /* end state */

    goto st81_error;

st82: {  /* DFA node {78,45,41,1} 82 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_8;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 4;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st83: {  /* DFA node {78} 83 */
    if (unlikely(i >= len)) {
        i++;
        goto st83_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 39: {
        goto st84;
        break;
        }
    case 92: {
        goto st85;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 38)
        || (c >= 40 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st83;
    }
    }  /* end state */

    goto st83_error;

st84: {  /* DFA node {80} 84 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st85: {  /* DFA node {75} 85 */
    if (unlikely(i >= len)) {
        i++;
        goto st85_error;
    }

    c = s[i];
    i++;
    if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
        goto st134;
    }
    }  /* end state */

    goto st85_error;

st87: {  /* DFA node {53} 87 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
            goto st87;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st88: {  /* DFA node {32,53} 88 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 61) {
            goto st135;
        }
        if (c == 91) {
            goto st136;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 92 && c <= 255))
        {
            /* transfer caps from row 1 to row 0 */
            caps0_10 = caps1_10;
            goto st87;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st91: {  /* DFA node {65,78,31,51,30,50,1} 91 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 3 to matched */
    matched_0 = caps3_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st138;
        }
        if (c == 39) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st139;
        }
        if (c == 91) {
            goto st140;
        }
        if (c == 92) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st141;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st137;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st92: {  /* DFA node {65,78,23,1} 92 */
    if (unlikely(i >= len)) {
        i++;
        goto st92_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 61: {
        goto st92;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st93;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st92_error;

st93: {  /* DFA node {65,78,25,21,1} 93 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_4;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 2;
    if (c != -1) {
        if (c == 34) {
            goto st105;
        }
        if (c == 39) {
            goto st106;
        }
        if (c == 92) {
            goto st107;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st104;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st94: {  /* DFA node {63,76,1} 94 */
    if (unlikely(i >= len)) {
        i++;
        goto st94_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st35;
    }  /* end state */

    goto st94_error;

st95: {  /* DFA node {63,76,59,1} 95 */
    if (unlikely(i >= len)) {
        i++;
        goto st95_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st95_error;

st96: {  /* DFA node {63,76,72,1} 96 */
    if (unlikely(i >= len)) {
        i++;
        goto st96_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st96_error;

st97: {  /* DFA node {63,76,30,50,1} 97 */
    if (unlikely(i >= len)) {
        i++;
        goto st97_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 4 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 4 to row 5 */
        /* transfer caps from row 4 to row 6 */
        /* capture stores */
        goto st91;
        break;
        }
    case 91: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        /* transfer caps from row 4 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 4 to row 2 */
    goto st35;
    }  /* end state */

    goto st97_error;

st98: {  /* DFA node {63,76,21,1} 98 */
    if (unlikely(i >= len)) {
        i++;
        goto st98_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 61: {
        goto st92;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st93;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st41;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st98_error;

st99: {  /* DFA node {63,76,41,1} 99 */
    if (unlikely(i >= len)) {
        i++;
        goto st99_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 61: {
        goto st102;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st103;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st99_error;

st100: {  /* DFA node {63,76,11,1} 100 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 34) {
            goto st105;
        }
        if (c == 39) {
            goto st106;
        }
        if (c == 92) {
            goto st107;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st104;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st101: {  /* DFA node {63,76,16,1} 101 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 34) {
            goto st105;
        }
        if (c == 39) {
            goto st106;
        }
        if (c == 92) {
            goto st107;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st104;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st102: {  /* DFA node {65,78,43,1} 102 */
    if (unlikely(i >= len)) {
        i++;
        goto st102_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st36;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st37;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st38;
        break;
        }
    case 61: {
        goto st102;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st39;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st40;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st103;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st42;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st43;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st35;
    }  /* end state */

    goto st102_error;

st103: {  /* DFA node {65,78,45,41,1} 103 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_8;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 4;
    if (c != -1) {
        if (c == 34) {
            goto st105;
        }
        if (c == 39) {
            goto st106;
        }
        if (c == 92) {
            goto st107;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st104;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st104: {  /* DFA node {65,78} 104 */
    if (unlikely(i >= len)) {
        i++;
        goto st104_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        goto st105;
        break;
        }
    case 39: {
        goto st106;
        break;
        }
    case 92: {
        goto st107;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 33)
        || (c >= 35 && c <= 38)
        || (c >= 40 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st104;
    }
    }  /* end state */

    goto st104_error;

st105: {  /* DFA node {67,78} 105 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st106: {  /* DFA node {65,80} 106 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st107: {  /* DFA node {62,75} 107 */
    if (unlikely(i >= len)) {
        i++;
        goto st107_error;
    }

    c = s[i];
    i++;
    if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
        goto st142;
    }
    }  /* end state */

    goto st107_error;

st108: {  /* DFA node {65,53} 108 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            goto st109;
        }
        if (c == 92) {
            goto st111;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st108;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st109: {  /* DFA node {67,53} 109 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st110: {  /* DFA node {65,32,53} 110 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st109;
        }
        if (c == 61) {
            goto st143;
        }
        if (c == 91) {
            goto st144;
        }
        if (c == 92) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st111;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st108;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st111: {  /* DFA node {62,53} 111 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
            goto st145;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st112: {  /* DFA node {63} 112 */
    if (unlikely(i >= len)) {
        i++;
        goto st112_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        goto st58;
        break;
        }
    case 92: {
        goto st59;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 33)
        || (c >= 35 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st57;
    }
    }  /* end state */

    goto st112_error;

st113: {  /* DFA node {78,65,31,51,30,50,1} 113 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 3 to matched */
    matched_0 = caps3_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st147;
        }
        if (c == 39) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st148;
        }
        if (c == 91) {
            goto st149;
        }
        if (c == 92) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st150;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st146;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st114: {  /* DFA node {78,65,23,1} 114 */
    if (unlikely(i >= len)) {
        i++;
        goto st114_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 61: {
        goto st114;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st115;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st114_error;

st115: {  /* DFA node {78,65,25,21,1} 115 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_4;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 2;
    if (c != -1) {
        if (c == 34) {
            goto st127;
        }
        if (c == 39) {
            goto st128;
        }
        if (c == 92) {
            goto st129;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st126;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st116: {  /* DFA node {76,63,1} 116 */
    if (unlikely(i >= len)) {
        i++;
        goto st116_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 2 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 2 to row 3 */
        /* transfer caps from row 2 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 91: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 2 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    goto st60;
    }  /* end state */

    goto st116_error;

st117: {  /* DFA node {76,63,59,1} 117 */
    if (unlikely(i >= len)) {
        i++;
        goto st117_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st117_error;

st118: {  /* DFA node {76,63,72,1} 118 */
    if (unlikely(i >= len)) {
        i++;
        goto st118_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st118_error;

st119: {  /* DFA node {76,63,30,50,1} 119 */
    if (unlikely(i >= len)) {
        i++;
        goto st119_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 4 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 4 to row 5 */
        /* transfer caps from row 4 to row 6 */
        /* capture stores */
        goto st113;
        break;
        }
    case 91: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        /* transfer caps from row 4 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 4 to row 2 */
        /* transfer caps from row 4 to row 3 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 4 to row 2 */
    goto st60;
    }  /* end state */

    goto st119_error;

st120: {  /* DFA node {76,63,21,1} 120 */
    if (unlikely(i >= len)) {
        i++;
        goto st120_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 61: {
        goto st114;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st115;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_8 = i - 1;
        goto st66;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st120_error;

st121: {  /* DFA node {76,63,41,1} 121 */
    if (unlikely(i >= len)) {
        i++;
        goto st121_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 61: {
        goto st124;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st125;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st121_error;

st122: {  /* DFA node {76,63,11,1} 122 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_0;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 0;
    if (c != -1) {
        if (c == 34) {
            goto st127;
        }
        if (c == 39) {
            goto st128;
        }
        if (c == 92) {
            goto st129;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st126;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st123: {  /* DFA node {76,63,16,1} 123 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_2;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 1;
    if (c != -1) {
        if (c == 34) {
            goto st127;
        }
        if (c == 39) {
            goto st128;
        }
        if (c == 92) {
            goto st129;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st126;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st124: {  /* DFA node {78,65,43,1} 124 */
    if (unlikely(i >= len)) {
        i++;
        goto st124_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 10: {
        /* transfer caps from row 3 to row 0 */
        goto st1;
        break;
        }
    case 34: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st61;
        break;
        }
    case 39: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        goto st62;
        break;
        }
    case 45: {
        /* transfer caps from row 3 to row 2 */
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        caps2_6 = i - 1;
        caps3_10 = i - 1;
        goto st63;
        break;
        }
    case 61: {
        goto st124;
        break;
        }
    case 91: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_4 = i - 1;
        goto st64;
        break;
        }
    case 92: {
        /* transfer caps from row 3 to row 2 */
        goto st65;
        break;
        }
    case 93: {
        /* transfer caps from row 3 to row 4 */
        /* capture stores */
        goto st125;
        break;
        }
    case 123: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_0 = i - 1;
        goto st67;
        break;
        }
    case 125: {
        /* transfer caps from row 3 to row 2 */
        /* capture stores */
        caps2_2 = i - 1;
        goto st68;
        break;
        }
    default:
        break;
    }
    /* (c >= 0 && c <= 9)
     * || (c >= 11 && c <= 33)
     * || (c >= 35 && c <= 38)
     * || (c >= 40 && c <= 44)
     * || (c >= 46 && c <= 60)
     * || (c >= 62 && c <= 90)
     * || (c >= 94 && c <= 122)
     * || (c == 124)
     * || (c >= 126 && c <= 255)
     */
    /* transfer caps from row 3 to row 2 */
    goto st60;
    }  /* end state */

    goto st124_error;

st125: {  /* DFA node {78,65,45,41,1} 125 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_8;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 4;
    if (c != -1) {
        if (c == 34) {
            goto st127;
        }
        if (c == 39) {
            goto st128;
        }
        if (c == 92) {
            goto st129;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st126;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st126: {  /* DFA node {78,65} 126 */
    if (unlikely(i >= len)) {
        i++;
        goto st126_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        goto st127;
        break;
        }
    case 39: {
        goto st128;
        break;
        }
    case 92: {
        goto st129;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 33)
        || (c >= 35 && c <= 38)
        || (c >= 40 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st126;
    }
    }  /* end state */

    goto st126_error;

st127: {  /* DFA node {78,67} 127 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st128: {  /* DFA node {80,65} 128 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st129: {  /* DFA node {75,62} 129 */
    if (unlikely(i >= len)) {
        i++;
        goto st129_error;
    }

    c = s[i];
    i++;
    if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
        goto st151;
    }
    }  /* end state */

    goto st129_error;

st130: {  /* DFA node {78,53} 130 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 39) {
            goto st131;
        }
        if (c == 92) {
            goto st133;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st130;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st131: {  /* DFA node {80,53} 131 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st132: {  /* DFA node {78,32,53} 132 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 39) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st131;
        }
        if (c == 61) {
            goto st152;
        }
        if (c == 91) {
            goto st153;
        }
        if (c == 92) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st133;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st130;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st133: {  /* DFA node {75,53} 133 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
            goto st154;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st134: {  /* DFA node {76} 134 */
    if (unlikely(i >= len)) {
        i++;
        goto st134_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 39: {
        goto st84;
        break;
        }
    case 92: {
        goto st85;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 38)
        || (c >= 40 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st83;
    }
    }  /* end state */

    goto st134_error;

st135: {  /* DFA node {34,53} 135 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 61) {
            goto st135;
        }
        if (c == 91) {
            goto st136;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 92 && c <= 255))
        {
            /* transfer caps from row 1 to row 0 */
            caps0_10 = caps1_10;
            goto st87;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st136: {  /* DFA node {36,53} 136 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_6;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 3;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st137: {  /* DFA node {65,78,53} 137 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            goto st138;
        }
        if (c == 39) {
            goto st139;
        }
        if (c == 92) {
            goto st141;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st137;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st138: {  /* DFA node {67,78,53} 138 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st139: {  /* DFA node {65,80,53} 139 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st140: {  /* DFA node {65,78,32,53} 140 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 3 to matched */
    matched_0 = caps3_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st138;
        }
        if (c == 39) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st139;
        }
        if (c == 61) {
            goto st156;
        }
        if (c == 91) {
            goto st157;
        }
        if (c == 92) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st141;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st137;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st141: {  /* DFA node {62,75,53} 141 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
            goto st158;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st142: {  /* DFA node {63,76} 142 */
    if (unlikely(i >= len)) {
        i++;
        goto st142_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        goto st105;
        break;
        }
    case 39: {
        goto st106;
        break;
        }
    case 92: {
        goto st107;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 33)
        || (c >= 35 && c <= 38)
        || (c >= 40 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st104;
    }
    }  /* end state */

    goto st142_error;

st143: {  /* DFA node {65,34,53} 143 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st109;
        }
        if (c == 61) {
            goto st143;
        }
        if (c == 91) {
            goto st144;
        }
        if (c == 92) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st111;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st108;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st144: {  /* DFA node {65,36,53} 144 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_6;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 3;
    if (c != -1) {
        if (c == 34) {
            goto st58;
        }
        if (c == 92) {
            goto st59;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st57;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st145: {  /* DFA node {63,53} 145 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            goto st109;
        }
        if (c == 92) {
            goto st111;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st108;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st146: {  /* DFA node {78,65,53} 146 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            goto st147;
        }
        if (c == 39) {
            goto st148;
        }
        if (c == 92) {
            goto st150;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st146;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st147: {  /* DFA node {78,67,53} 147 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_12;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 6;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st148: {  /* DFA node {80,65,53} 148 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 0 to matched */
    matched_0 = caps0_14;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 7;
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st149: {  /* DFA node {78,65,32,53} 149 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 3 to matched */
    matched_0 = caps3_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st147;
        }
        if (c == 39) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st148;
        }
        if (c == 61) {
            goto st159;
        }
        if (c == 91) {
            goto st160;
        }
        if (c == 92) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st150;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st146;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st150: {  /* DFA node {75,62,53} 150 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if ((c >= 0 && c <= 9) || (c >= 11 && c <= 255)) {
            goto st161;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st151: {  /* DFA node {76,63} 151 */
    if (unlikely(i >= len)) {
        i++;
        goto st151_error;
    }

    c = s[i];
    i++;
    switch (c) {
    case 34: {
        goto st127;
        break;
        }
    case 39: {
        goto st128;
        break;
        }
    case 92: {
        goto st129;
        break;
        }
    default:
        break;
    }
    if ((c >= 0 && c <= 9)
        || (c >= 11 && c <= 33)
        || (c >= 35 && c <= 38)
        || (c >= 40 && c <= 91)
        || (c >= 93 && c <= 255))
    {
        goto st126;
    }
    }  /* end state */

    goto st151_error;

st152: {  /* DFA node {78,34,53} 152 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 39) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st131;
        }
        if (c == 61) {
            goto st152;
        }
        if (c == 91) {
            goto st153;
        }
        if (c == 92) {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st133;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 2 to row 1 */
            caps1_10 = caps2_10;
            goto st130;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st153: {  /* DFA node {78,36,53} 153 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_6;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 3;
    if (c != -1) {
        if (c == 39) {
            goto st84;
        }
        if (c == 92) {
            goto st85;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st83;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st154: {  /* DFA node {76,53} 154 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 1 to matched */
    matched_0 = caps1_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 39) {
            goto st131;
        }
        if (c == 92) {
            goto st133;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st130;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st156: {  /* DFA node {65,78,34,53} 156 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 3 to matched */
    matched_0 = caps3_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st138;
        }
        if (c == 39) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st139;
        }
        if (c == 61) {
            goto st156;
        }
        if (c == 91) {
            goto st157;
        }
        if (c == 92) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st141;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st137;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st157: {  /* DFA node {65,78,36,53} 157 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_6;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 3;
    if (c != -1) {
        if (c == 34) {
            goto st105;
        }
        if (c == 39) {
            goto st106;
        }
        if (c == 92) {
            goto st107;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st104;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st158: {  /* DFA node {63,76,53} 158 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            goto st138;
        }
        if (c == 39) {
            goto st139;
        }
        if (c == 92) {
            goto st141;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st137;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st159: {  /* DFA node {78,65,34,53} 159 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 3 to matched */
    matched_0 = caps3_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st147;
        }
        if (c == 39) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st148;
        }
        if (c == 61) {
            goto st159;
        }
        if (c == 91) {
            goto st160;
        }
        if (c == 92) {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st150;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 60)
            || (c >= 62 && c <= 90)
            || (c >= 93 && c <= 255))
        {
            /* transfer caps from row 3 to row 2 */
            caps2_10 = caps3_10;
            goto st146;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st160: {  /* DFA node {78,65,36,53} 160 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_6;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 3;
    if (c != -1) {
        if (c == 34) {
            goto st127;
        }
        if (c == 39) {
            goto st128;
        }
        if (c == 92) {
            goto st129;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st126;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st161: {  /* DFA node {76,63,53} 161 */
    c = i < len ? s[i] : -1;
    i++;
    /* transfer caps from row 2 to matched */
    matched_0 = caps2_10;
    /* capture stores */
    matched_1 = i - 1;
    matched_id = 5;
    if (c != -1) {
        if (c == 34) {
            goto st147;
        }
        if (c == 39) {
            goto st148;
        }
        if (c == 92) {
            goto st150;
        }
        if ((c >= 0 && c <= 9)
            || (c >= 11 && c <= 33)
            || (c >= 35 && c <= 38)
            || (c >= 40 && c <= 91)
            || (c >= 93 && c <= 255))
        {
            goto st146;
        }
    }
    }  /* end state */

    ovec[0] = matched_0;
    ovec[1] = matched_1;
    return matched_id;  /* fallback */

st0_error:
st1_error:
st2_error:
st3_error:
st4_error:
st5_error:
st6_error:
st9_error:
st11_error:
st12_error:
st13_error:
st14_error:
st15_error:
st18_error:
st19_error:
st21_error:
st22_error:
st23_error:
st24_error:
st28_error:
st30_error:
st35_error:
st38_error:
st39_error:
st40_error:
st41_error:
st45_error:
st47_error:
st48_error:
st49_error:
st50_error:
st51_error:
st52_error:
st55_error:
st57_error:
st59_error:
st60_error:
st63_error:
st64_error:
st65_error:
st66_error:
st71_error:
st73_error:
st74_error:
st75_error:
st76_error:
st77_error:
st78_error:
st81_error:
st83_error:
st85_error:
st92_error:
st94_error:
st95_error:
st96_error:
st97_error:
st98_error:
st99_error:
st102_error:
st104_error:
st107_error:
st112_error:
st114_error:
st116_error:
st117_error:
st118_error:
st119_error:
st120_error:
st121_error:
st124_error:
st126_error:
st129_error:
st134_error:
st142_error:
st151_error:

    if (matched_0 != -1) {
        ovec[0] = matched_0;
        ovec[1] = matched_1;
        return matched_id;  /* fallback */
    }
    return NO_MATCH;
}
